@@ -3,8 +3,6 @@ developed within the scope of the research project iHEM (intelligent
 Home Energy Management).
 
 """
-from datetime import datetime
-
 from pysimmods.generator.pvsim.config import PVConfig
 from pysimmods.generator.pvsim.inputs import PVInputs
 from pysimmods.generator.pvsim.state import PVState
@@ -103,7 +101,7 @@ class PhotovoltaicPowerPlant(Generator):
         else:
             if self.inputs.bh_w_per_m2 > 2 or self.inputs.dh_w_per_m2 > 2:
                 sun_pos = solargeometry.compute_sun_position(
-                    self.inputs.now.timestamp(),
+                    self.inputs.now_dt.timestamp(),
                     self.config.lat_deg,
                     self.config.lon_deg,
                 )
@@ -164,7 +162,7 @@ class PhotovoltaicPowerPlant(Generator):
         # irradiance equals the irradiance at standard conditions
         # (1000 Watt/m2)
 
-        self.state.p_kw = -(
+        self.state.p_kw = (
             irradiance_w_per_m2
             * self.config.eta_percent
             / 100
@@ -180,7 +178,7 @@ class PhotovoltaicPowerPlant(Generator):
         if not self.config.has_external_irradiance_model:
             error = error or self.inputs.bh_w_per_m2 is None
             error = error or self.inputs.dh_w_per_m2 is None
-            error = error or self.inputs._now is None
+            error = error or self.inputs.now_dt is None
 
         if error:
             raise KeyError("At least one input is not set")
